NAME = "ferfereh"

ICON = "🌀"

DESCRIPTION = f"{ICON} 3d-printed graffiti."

VERSION = "1.147.1"

MARQUEE = "https://user-images.githubusercontent.com/1007567/221448494-d57e08c1-625b-499e-a576-81894f112d6a.jpg"
